@@ -1,9 +1,10 @@
 from django.contrib import admin
-from django.contrib.auth.models import User
 from django.contrib.auth.admin import UserAdmin
 
-from relationships.forms import RelationshipStatusAdminForm
-from relationships.models import Relationship, RelationshipStatus
+from .compat import User
+from .forms import RelationshipStatusAdminForm
+from .models import Relationship, RelationshipStatus
+
 
 class RelationshipInline(admin.TabularInline):
     model = Relationship
@@ -11,6 +12,7 @@ class RelationshipInline(admin.TabularInline):
     extra = 1
     fk_name = 'from_user'
 
+
 class UserRelationshipAdmin(UserAdmin):
     inlines = (RelationshipInline,)
 
