@@ -1,6 +1,8 @@
 from django import forms
 from django.db.models import Q
-from relationships.models import RelationshipStatus
+
+from .models import RelationshipStatus
+
 
 class RelationshipStatusAdminForm(forms.ModelForm):
     class Meta:
@@ -17,7 +19,7 @@ class RelationshipStatusAdminForm(forms.ModelForm):
             status_qs = status_qs.exclude(pk=self.instance.pk)
 
         if status_qs.exists():
-            raise forms.ValidationError('"%s" slug already in use on %s' % \
+            raise forms.ValidationError('"%s" slug already in use on %s' %
                 (status_slug, unicode(status_qs[0])))
 
     def clean_from_slug(self):
@@ -35,10 +37,10 @@ class RelationshipStatusAdminForm(forms.ModelForm):
     def clean(self):
         if self.errors:
             return self.cleaned_data
-        
+
         if self.cleaned_data['from_slug'] == self.cleaned_data['to_slug'] or \
            self.cleaned_data['to_slug'] == self.cleaned_data['symmetrical_slug'] or \
            self.cleaned_data['symmetrical_slug'] == self.cleaned_data['from_slug']:
             raise forms.ValidationError('from, to, and symmetrical slugs must be different')
-        
+
         return self.cleaned_data
